==> microsoft.bingads-13.0.16.1-sources.jar: com/microsoft/bingads/v13/campaignmanagement/ArrayOfAudienceGroup.java <==

package com.microsoft.bingads.v13.campaignmanagement;

import java.util.ArrayList;
import java.util.List;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ArrayOfAudienceGroup complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="ArrayOfAudienceGroup">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element name="AudienceGroup" type="{https://bingads.microsoft.com/CampaignManagement/v13}AudienceGroup" maxOccurs="unbounded" minOccurs="0"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ArrayOfAudienceGroup", propOrder = {
    "audienceGroups"
})
public class ArrayOfAudienceGroup {

    @XmlElement(name = "AudienceGroup", nillable = true)
    protected List<AudienceGroup> audienceGroups;

    /**
     * Gets the value of the audienceGroups property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the Jakarta XML Binding object.
     * This is why there is not a {@code set} method for the audienceGroups property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getAudienceGroups().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link AudienceGroup }
     * 
     * 
     * @return
     *     The value of the audienceGroups property.
     */
    public List<AudienceGroup> getAudienceGroups() {
        if (audienceGroups == null) {
            audienceGroups = new ArrayList<>();
        }
        return this.audienceGroups;
    }

}

==> microsoft.bingads-13.0.23-sources.jar: com/microsoft/bingads/v13/campaignmanagement/ArrayOfAudienceGroup.java <==

package com.microsoft.bingads.v13.campaignmanagement;

import java.util.ArrayList;
import java.util.List;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;
import com.fasterxml.jackson.annotation.JsonCreator;

/**
 * <p>Java class for ArrayOfAudienceGroup complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="ArrayOfAudienceGroup">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element name="AudienceGroup" type="{https://bingads.microsoft.com/CampaignManagement/v13}AudienceGroup" maxOccurs="unbounded" minOccurs="0"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ArrayOfAudienceGroup", propOrder = {
    "audienceGroups"
})
public class ArrayOfAudienceGroup {

    @XmlElement(name = "AudienceGroup", nillable = true)
    protected List<AudienceGroup> audienceGroups;
    public ArrayOfAudienceGroup()
    {
      this.audienceGroups = new ArrayList<AudienceGroup>();
    }
    @JsonCreator
    public ArrayOfAudienceGroup(List<AudienceGroup> audiencegroups)
    {
      this.audienceGroups = audiencegroups;
    }

    /**
     * Gets the value of the audienceGroups property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the Jakarta XML Binding object.
     * This is why there is not a {@code set} method for the audienceGroups property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getAudienceGroups().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link AudienceGroup }
     * 
     * 
     * @return
     *     The value of the audienceGroups property.
     */
    public List<AudienceGroup> getAudienceGroups() {
        if (audienceGroups == null) {
            audienceGroups = new ArrayList<>();
        }
        return this.audienceGroups;
    }

}
